summaryrefslogtreecommitdiff
path: root/makima/frontend/src/components/contracts/ContractCliInput.tsx
diff options
context:
space:
mode:
Diffstat (limited to 'makima/frontend/src/components/contracts/ContractCliInput.tsx')
-rw-r--r--makima/frontend/src/components/contracts/ContractCliInput.tsx6
1 files changed, 3 insertions, 3 deletions
diff --git a/makima/frontend/src/components/contracts/ContractCliInput.tsx b/makima/frontend/src/components/contracts/ContractCliInput.tsx
index 821d03c..54d9f3a 100644
--- a/makima/frontend/src/components/contracts/ContractCliInput.tsx
+++ b/makima/frontend/src/components/contracts/ContractCliInput.tsx
@@ -279,9 +279,9 @@ export function ContractCliInput({ contractId, contract, onUpdate }: ContractCli
}
}, [messages]);
// Auto-start supervisor when component mounts if it's pending
useEffect(() => {
- if (supervisorTask && isSupervisorPending && !supervisorStarting) {
+ if (supervisorTask && isSupervisorPending && !supervisorStarting && contract.status !== 'completed') {
console.log("Auto-starting supervisor task on mount...");
ensureSupervisorStarted().then((started) => {
if (started) {
@@ -289,7 +289,7 @@ export function ContractCliInput({ contractId, contract, onUpdate }: ContractCli
}
});
}
- }, [supervisorTask?.id]); // Only run when task ID changes, not on every render
+ }, [supervisorTask?.id, contract.status]); // Only run when task ID or contract status changes
// Convert supervisor output events to messages
useEffect(() => {
@@ -279,9 +279,9 @@ export function ContractCliInput({ contractId, contract, onUpdate }: ContractCli
}
}, [messages]);
- // Auto-start supervisor when component mounts if it's pending
+ // Auto-start supervisor when component mounts if it's pending (but not for completed contracts)
useEffect(() => {